@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Portions copyright (C) 1998-1999 Niels Mller
+ * Copyright (c) 1998-1999 Niels Mller
  * Copyright (c) 1999 BalaBit Computing
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: format.h,v 1.3 1999/05/06 15:26:44 bazsi Exp $
+ * $Id: format.h,v 1.5.2.1 2001/10/24 10:43:22 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -28,6 +28,16 @@
 
 #include <stdarg.h>
 
+#ifndef va_copy
+#  ifdef __va_copy
+#    define va_copy __va_copy
+#  endif
+#endif
+
+#ifndef va_copy
+#define va_copy(a, b)
+#endif
+
 struct ol_string *c_format(const char *format, ...);
 UINT32 c_format_length(const char *format, ...);
 UINT32 c_format_write(const char *format, UINT32 length, UINT8 *buffer, ...);
