@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.25 2001/08/26 21:28:18 bazsi Exp $ */
+ * $Id: io.c,v 1.25.2.1 2003/02/12 10:49:09 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -238,7 +238,7 @@ int io_iter(struct io_backend *b)
 					WRITE_FD(fd);
 				else {
 					verbose("io_iter(): POLLHUP on inactive fd!\n");
-					close_fd(fd, CLOSE_EOF);
+					closekill_fd(fd, CLOSE_EOF);
 				}
 				continue;
 			}
