@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: pkt_buffer.c,v 1.11 2001/08/26 21:28:18 bazsi Exp $
+ * $Id: pkt_buffer.c,v 1.12 2001/10/11 18:18:58 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -27,8 +27,6 @@
 #include "io.h"
 #include "format.h"
 
-int pktbuf_dropped_pkts;
-
 struct buffer_node {
 	struct ol_queue_node header;
 	struct ol_string *packet;
@@ -72,7 +70,6 @@ static int do_write_str(struct abstract_write *c, struct ol_string *string)
 	}
 	if (self->queue_size == self->queue_max) {
 		/* fifo full */
-		pktbuf_dropped_pkts++;
 		ol_string_free(string);
 		return ST_FAIL | ST_OK;
 	}
@@ -91,59 +88,36 @@ static int do_write_str(struct abstract_write *c, struct ol_string *string)
 static int do_flush(struct abstract_buffer *c, struct abstract_write *w)
 {
 	CAST(pkt_buffer, self, c); 
-	char buffer[4096];
-	int end = 0;
  	int res;
 
 	FOR_QUEUE(&self->queue, struct buffer_node *, item) {
-		int avail = sizeof(buffer) - end;
-		int move = MIN(item->packet->length, avail);
-		
-		
-		if (avail == 0)
-			break;
-		memcpy(&buffer[end], item->packet->data, move);
-		end += move;
-		
-		if (item->packet->length != move) {
-			struct ol_string *s;
-			s = item->packet;
-			item->packet = c_format("%s", s->length - res, s->data + res);
-			ol_string_free(s);
-		} 
-		else {
-		
-			/* successfully moved */
-			self->queue_size--;
-			ol_queue_remove((struct ol_queue_node *) item);
-			ol_string_free(item->packet);
-			ol_space_free(item);
-		}
-	}
 
-	res = A_WRITE(w, end, buffer);
-	
-	if (res >= 0) {
-		if (end == res) {
-			if (self->super.writable)
-				(*self->super.writable) = 1;
+		res = A_WRITE(w, item->packet->length, item->packet->data);
+		if (res >= 0) {
+			if (item->packet->length == res) {
+				self->queue_size--;
+				ol_queue_remove((struct ol_queue_node *) item);
+				ol_string_free(item->packet);
+				ol_space_free(item);
+				if (self->super.writable)
+					(*self->super.writable) = 1;
+			}
+			else if (res != 0) {
+				struct ol_string *s;
+				s = item->packet;
+				item->packet = c_format("%s", s->length - res, s->data + res);
+				ol_string_free(s);
+				break;
+			}
+			else {
+				break;
+			}
 		}
-		else if (res != 0) {
-			/* this is slow, because of another memory move
-			 * but this is run rarely anyway */
-			struct buffer_node *item;
-		
-			NEW_SPACE(item);
-			item->packet = c_format("%s", end - res, buffer + res);
-			ol_queue_add_head(&self->queue, &item->header);
-			if (++self->queue_size == self->queue_max && self->super.writable)
-				(*self->super.writable) = 0;
+		else {
+			verbose("pkt_buffer::do_flush(): Error flushing data\n");
+			return ST_DIE;
 		}
 	}
-	else {
-		werror("pkt_buffer::do_flush(): Error flushing data\n");
-		return ST_DIE;
-	}
 	return ST_OK | ST_GOON;
 }
 
@@ -185,5 +159,6 @@ struct abstract_buffer *make_pkt_buffer_ext(int queue_min, int queue_max)
 {
 	struct abstract_buffer *b = make_pkt_buffer(queue_max);
 	((struct pkt_buffer *) b)->queue_min = queue_min;
+
 	return b;
 }
