@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: werror.c,v 1.3 1999/04/26 20:28:52 bazsi Exp $
+ * $Id: werror.c,v 1.4.2.1 2001/10/24 10:43:22 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -117,9 +117,12 @@ void msg_vformat(int level, const char *f, va_list args)
 {
 	UINT8 errorbuf[BUF_SIZE];
 	int length;
+	va_list args_copy;
+	va_copy(args_copy, args);
 	
 	length = c_vformat_length(f, args);
 	if (length <= BUF_SIZE) {
+		va_copy(args, args_copy);
 		c_vformat_write(f, sizeof(errorbuf), errorbuf, args);
 		MSG_WRITE(level, length, errorbuf);
 	}
